@@ -28,6 +28,10 @@ def get_column_value_strings(columns, query_type='insert'):
 
 class MySQLTools:
     def __init__(self, config):
+        """
+        Connect to MySQL database and execute queries
+        :param config: MySQL server configuration settings
+        """
         self.cursor = None
         self.cnx = None
         self.connect(config)
